pub trait AudioOutputStream: AudioStream + AudioOutputStreamSafe {
// Required methods
fn pause_with_timeout(&mut self, timeout_nanoseconds: i64) -> Status;
fn flush_with_timeout(&mut self, timeout_nanoseconds: i64) -> Status;
fn request_pause(&mut self) -> Status;
fn request_flush(&mut self) -> Status;
// Provided methods
fn pause(&mut self) -> Status { ... }
fn flush(&mut self) -> Status { ... }
}Expand description
The stream which has pause/flush capabilities
Required Methods
Sourcefn pause_with_timeout(&mut self, timeout_nanoseconds: i64) -> Status
fn pause_with_timeout(&mut self, timeout_nanoseconds: i64) -> Status
Pause the stream. This will block until the stream has been paused, an error occurs
or timeoutNanoseconds has been reached.
Sourcefn flush_with_timeout(&mut self, timeout_nanoseconds: i64) -> Status
fn flush_with_timeout(&mut self, timeout_nanoseconds: i64) -> Status
Flush the stream. This will block until the stream has been flushed, an error occurs
or timeoutNanoseconds has been reached.
Sourcefn request_pause(&mut self) -> Status
fn request_pause(&mut self) -> Status
Pause the stream asynchronously. Returns immediately (does not block). Equivalent to calling
pause(0).
Sourcefn request_flush(&mut self) -> Status
fn request_flush(&mut self) -> Status
Flush the stream asynchronously. Returns immediately (does not block). Equivalent to calling
flush(0).
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".